__name__ = "picogo"
__package__ = "picogo"
__version__ = '0.0.7'
__author__ = "SkySLAM Co., Ltd."

from .Robot import (
    Robot , 
)

from .MainFileCopy import main_file_copy

print( "picogo __init__.py executed." ) 